<?php

/***
Plugin Name: Easy Email Checkout
Plugin URI: https://frontseries.gr/
Description: Make the email field in checkout process easier for your customers by suggest autocomplete email services.
Version: 1.0.1
Author: Front Series
Author URI: https://frontseries.gr/contact/
WC requires at least: 5.0
WC tested up to: 5.6
License: GPLv2 or later
***/

if( !defined('ABSPATH') ) {
	die( 'You are not allowed to call this page directly.' );
}

// Defines
define( 'EASY_EMAIL_CHECKOUT__VERSION', '1.0.1' );
define( 'EASY_EMAIL_CHECKOUT__BASENAME', plugin_basename(dirname(__FILE__)) );
define( 'EASY_EMAIL_CHECKOUT__DIR', plugin_dir_path(__FILE__) );

if ( ! class_exists( 'EasyEmailCheckout' ) ) :

Class EasyEmailCheckout {

	private $options;

	/**
	 * Initialize the Plugin
	 * @since  1.0.0
	 */
	public function __construct() {

		$this->init_assets();
		add_action( 'admin_menu', array($this, 'menu_init') );
		add_action( 'admin_menu', array($this, 'page_init') );

	}

	/**
	 * Initialize the Assets
	 * @since  1.0.0
	 */
	public function init_assets() {

		if (is_admin()) {

		    wp_register_style( 'easyemailcheckout', plugins_url('/assets/css/style.css', __FILE__), false, EASY_EMAIL_CHECKOUT__VERSION, 'all' );
		    wp_register_style( 'easyemailcheckout-tags-style', plugins_url('/assets/css/tags.css', __FILE__), false, EASY_EMAIL_CHECKOUT__VERSION, 'all' );
		    wp_enqueue_style('easyemailcheckout-tags-style');
			wp_enqueue_style('easyemailcheckout');
			wp_enqueue_script( 'easymailcheckout-tags', plugins_url( '/assets/js/tags.js', __FILE__ ));
			wp_enqueue_script( 'easymailcheckout-js', plugins_url( '/assets/js/easyemailcheckout.js', __FILE__ ));

		}

	}

	/**
	 * Initialize Admin Menu
	 * @since  1.0.0
	 */
	public function menu_init() {

		add_options_page(
    		'Easy Email Checkout',
        	'Easy Email Checkout',
        	'manage_options',
        	'easy-email-checkout-settings',
        	array($this, 'admin_page')
    	);

	}


    public function page_init() {

        register_setting(
            'fs_eec_settings',
            'fs_eec_domains',
            array( $this, 'sanitize' )
        );

        add_settings_section(
            'fs_eec_domains_selected',
            'Selected Domains',
            array( $this, 'print_section_info' ),
            'fs_eec_admin_settings'
        );  

    }


    public function sanitize( $input ) {

        $new_input = array();

        if( isset( $input['fs_eec_domains_selected'] ) )
            $new_input['fs_eec_domains_selected'] = sanitize_text_field( $input['fs_eec_domains_selected'] );

        return $new_input;
    }


    public function print_section_info() {

        printf(
            '<input name="fs_eec_domains[fs_eec_domains_selected]" class="easyemail_tags" placeholder="Enter or select domain" value="%s" />',
            isset( $this->options['fs_eec_domains_selected'] ) ? esc_attr( $this->options['fs_eec_domains_selected']) : ''
        );

    }


	public function admin_page() {

		$this->options = get_option( 'fs_eec_domains' );

		?>
			<div class="wrap" id="easyemailcheckout-main">

				<h1>Easy Email Checkout for WooCommerce</h1>

				<form method="post" action="options.php">

					<?php
						settings_fields( 'fs_eec_settings' );
						do_settings_sections( 'fs_eec_admin_settings' );
						submit_button();
					?>
					
				</form>

			</div>
		<?php
	}

}

endif;

if( is_admin() ) {

	$EasyEmailCheckout = new EasyEmailCheckout();
	add_action( 'admin_post_easy_email_checkout_settings_save', array($EasyEmailCheckout, 'save_settings'));

}

add_filter( 'woocommerce_before_checkout_form' , 'EasyEmailCheckoutInitFront' );

function EasyEmailCheckoutInitFront( $fields ) {

	wp_register_style( 'easyemailcheckout-front', plugins_url('/assets/css/style-front.css', __FILE__), false, EASY_EMAIL_CHECKOUT__VERSION, 'all' );
    wp_enqueue_style('easyemailcheckout-front');
	wp_enqueue_script( 'easymailcheckout-js', plugins_url( '/assets/js/easyemailcheckout-front.js', __FILE__ ));

	$options = get_option( 'fs_eec_domains' )['fs_eec_domains_selected'];
	$options = json_decode($options, true);

	$html = '<div id="easymailcheckout-domains">';

	if (!empty($options)) {
		
		foreach ($options as $option) {
			$html .= '<div class="easyemailcheckout-domains_option" data-email="'.$option['value'].'"><div class="easyemailcheckout-domains_option__email"></div>@' . $option['value'] . '</div>';
		}
	}

	$html .= '</div>';

	?>
	<script>
		jQuery(document).ready(function($) {
			$('input[name="billing_email"]').after('<?php echo $html ;?>');
		});
	</script>
	<?php
}
?>